==> xcsoar-6.6.5.tar.bz2: xcsoar-6.6.5/src/Replay/DemoReplay.cpp <==
/*
Copyright_License {

  XCSoar Glide Computer - http://www.xcsoar.org/
  Copyright (C) 2000-2013 The XCSoar Project
  A detailed list of copyright holders can be found in the file "AUTHORS".

  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
  as published by the Free Software Foundation; either version 2
  of the License, or (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
}
*/
#include "DemoReplay.hpp"

DemoReplay::DemoReplay():
  parms(),
  autopilot(parms),
  aircraft()
{
}

void
DemoReplay::Start(const TaskAccessor& task, const GeoPoint& default_location)
{
  autopilot.SetDefaultLocation(default_location);
  autopilot.Start(task);
  aircraft.Start(autopilot.location_start, autopilot.location_previous,
                 parms.start_alt);
}

bool
DemoReplay::Update(fixed time_scale, TaskAccessor& task)
{
  autopilot.UpdateState(task, aircraft.GetState(), time_scale);
  aircraft.Update(autopilot.heading, time_scale);
  return autopilot.UpdateAutopilot(task, aircraft.GetState(),
                                   aircraft.GetLastState());
}

==> xcsoar-6.7.1.tar.bz2: xcsoar-6.7.1/src/Replay/DemoReplay.cpp <==
/*
Copyright_License {

  XCSoar Glide Computer - http://www.xcsoar.org/
  Copyright (C) 2000-2013 The XCSoar Project
  A detailed list of copyright holders can be found in the file "AUTHORS".

  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
  as published by the Free Software Foundation; either version 2
  of the License, or (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
}
*/
#include "DemoReplay.hpp"

DemoReplay::DemoReplay():
  parms(),
  autopilot(parms),
  aircraft()
{
}

void
DemoReplay::Start(const TaskAccessor& task, const GeoPoint& default_location)
{
  autopilot.SetDefaultLocation(default_location);
  autopilot.Start(task);
  aircraft.Start(autopilot.location_start, autopilot.location_previous,
                 parms.start_alt);
}

bool
DemoReplay::Update(fixed time_scale, TaskAccessor& task)
{
  autopilot.UpdateState(task, aircraft.GetState(), time_scale);
  aircraft.Update(autopilot.heading, time_scale);
  return autopilot.UpdateAutopilot(task, aircraft.GetState());
}
